pub fn execute_commands(
cmds: Vec<Exec>,
io_error_message: &str,
error_while_running_message: &str,
) -> Result<(), DotfilesError>Expand description
Executes the cmd and waits for it to finish.
If the execution returns a std::io::Error then it uses the io_error_message
for the message in a DotfilesError.
If the execution finishes but in an error state, then it uses the
error_while_running_message instead.